@@ -1,16 +1,17 @@
 import re
+from typing import Dict, List
 
 from ..type_specs import HotkeysWithModes
 from ._base import Parser
-from .sources import Command, Manpage
+from .sources import Command, ManPage
 
 
 class Termite(Parser):
     required = bool(Command("termite"))
-    sources = {"default": [Manpage("termite")]}
+    sources = {"default": [ManPage("termite")]}
     has_modes = True
 
-    def parse(self, fetched) -> HotkeysWithModes:
+    def parse(self, fetched: Dict[str, List[str]]) -> HotkeysWithModes:
         content = fetched["default"][0]
         # remove some stray groff tags
         content_clean = re.compile(r"(\\f[PBI])")
