@@ -1,28 +1,29 @@
 import re
+from typing import Dict, List
 
 from ..type_specs import HotkeysWithModes
 from ._base import Parser, SectionParse
-from .sources import Command, Manpage
+from .sources import Command, ManPage
 
 
 class Zathura(SectionParse, Parser):
     required = bool(Command("zathura"))
-    sources = {"default": [Manpage("zathura")]}
+    sources = {"default": [ManPage("zathura")]}
     has_modes = True
 
     @staticmethod
-    def _clean_action(string):
+    def _clean_action(string: str) -> str:
         string = string.replace("\\fB", "").replace("\\fP", "")
         string = string.replace("\\-", "-")
         string = string[: string.index("\n")] + "."
         return string
 
     @staticmethod
-    def _clean_key(string):
+    def _clean_key(string: str) -> str:
         string = string.replace("\\-", "-").replace("\\(aq", "'")
         return string
 
-    def parse(self, fetched) -> HotkeysWithModes:
+    def parse(self, fetched: Dict[str, List[str]]) -> HotkeysWithModes:
         content = fetched["default"][0]
         # select section from manpage
         content_section = re.compile(r"\.SH MOUSE AND KEY BINDINGS.*?\.SH", re.DOTALL)
